@@ -20,7 +20,7 @@ def get_app_status(env: Environment, exposed_fields=("name", "description", "ver
     """
     Gets the Cloud Function Status from the environment object and augments with Health information.
 
-    By Default exposes the app name, description and version and sets the health status to OK
+    By Default exposes the app name, description, version and active_profiles and sets the health status to OK
 
     Example Usage:
 
@@ -45,6 +45,8 @@ def get_app_status(env: Environment, exposed_fields=("name", "description", "ver
         if k in exposed_fields:
             resp[k] = v
 
+    resp["active_profiles"] = env.active_profiles
+
     if health_check:
         health_check(resp)
 
